import { request } from '../../../utils';
import { API } from '../../../types';
import { ResponseType } from '../response-type';
import { UserRegistrationData } from './queries/use-post-register';

export interface PostLoginUserReturn extends ResponseType {
  token: string;
}

export interface PostRegisterUserReturn extends ResponseType {
  token: string;
  uid: string;
  mail: 1 | 0;
}

export const authApi = {
  loginUser: (data: { login: string; pass: string }) =>
    request.postForm<PostLoginUserReturn>(API.LOGIN, data),
  registerUser: (data: UserRegistrationData) => {
    const formData = new FormData();

    formData.append('user', JSON.stringify(data.user));
    formData.append('photo', {
      type: data.photo.type,
      uri: data.photo.uri,
      name: data.photo.name
    } as unknown as Blob);

    return request.postForm<PostRegisterUserReturn>(API.REGISTER, formData);
  }
};
